@@ -385,7 +385,6 @@ def General_Explicit(order,W,A,n,F,y_init,limit=[0,1],C=None):
         C=np.asarray(C)
     else:
         C=np.sum(A,axis=1)
-        print(C)
     
     for i in range(n-1):
         x_i=a+i*h
@@ -732,7 +731,6 @@ def  Adams_Bashforth_Moulton_PC(n,F,y_list,limit=[0,1],correct_count=1):
         for k in range(4):
             net+=coeff_P[k]*F(x=x_init-step*k,y=y_list[-k-1])
         y_p = y_list[-1]+step*net
-        print("pred  "+str(i)+" "+str(y_p)+"\n")
         ## corrector
 
         for j in range(correct_count):
@@ -740,7 +738,6 @@ def  Adams_Bashforth_Moulton_PC(n,F,y_list,limit=[0,1],correct_count=1):
             for k in range(3):
                 net+=coeff_C[k+1]*F(x=x_init-step*k,y=y_list[-k-1])
             y_p=y_list[-1]+step*net
-            print(str(j+1)+" "+str(y_p))
         
         y_list.append(y_p)
         x_init+=step
@@ -781,7 +778,6 @@ def Milne_PC(n,F,y_list,limit=[0,1],correct_count=1):
         for k in range(3):
             net+=coeff_P[k]*F(x=x_init-step*k,y=y_list[-k-1])
         y_p = y_list[-4]+step*net
-        print("pred  "+str(i)+" "+str(y_p)+"\n")
         ## corrector
 
         for j in range(correct_count):
@@ -789,7 +785,6 @@ def Milne_PC(n,F,y_list,limit=[0,1],correct_count=1):
             for k in range(2):
                 net+=coeff_C[k+1]*F(x=x_init-step*k,y=y_list[-k-1])
             y_p=y_list[-2]+step*net
-            print(str(j+1)+" "+str(y_p))
         
         y_list.append(y_p)
         x_init+=step
@@ -825,12 +820,10 @@ def Euler_PC(n,F,y_list,limit=[0,1],correct_count=1):
 
         ##predictor
         y_p = y_list[-1]+step*F(x=x_init,y=y_list[-1])
-        print("pred  "+str(i)+" "+str(y_p)+"\n")
 
         ##corrector
         for j in range(correct_count):
             y_p=y_list[-1]+step*F(x=x_init+step,y=y_p)
-            print(str(j+1)+" "+str(y_p))
         
         y_list.append(y_p)
         x_init+=step
